==> anytun_0.3.3.orig.tar.gz: anytun-0.3.3/src/syncBuffer.h <==
/*
 *  anytun
 *
 *  The secure anycast tunneling protocol (satp) defines a protocol used
 *  for communication between any combination of unicast and anycast
 *  tunnel endpoints.  It has less protocol overhead than IPSec in Tunnel
 *  mode and allows tunneling of every ETHER TYPE protocol (e.g.
 *  ethernet, ip, arp ...). satp directly includes cryptography and
 *  message authentication based on the methodes used by SRTP.  It is
 *  intended to deliver a generic, scaleable and secure solution for
 *  tunneling and relaying of packets of any protocol.
 *
 *
 *  Copyright (C) 2007-2009 Othmar Gsenger, Erwin Nindl, 
 *                          Christian Pointner <satp@wirdorange.org>
 *
 *  This file is part of Anytun.
 *
 *  Anytun is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.
 *
 *  Anytun is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with anytun.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ANYTUN_syncBuffer_h_INCLUDED
#define ANYTUN_syncBuffer_h_INCLUDED

#include <boost/archive/text_oarchive.hpp>
#include <boost/archive/text_iarchive.hpp>
#include "buffer.h"
#include <iostream>
#include "datatypes.h"
#include "threadUtils.hpp"

class SyncBuffer : public Buffer
{
public:
		SyncBuffer() : Buffer(){};
		SyncBuffer(u_int32_t length) : Buffer(length){};
		SyncBuffer(Buffer b): Buffer(b) {};
		SyncBuffer(u_int8_t* data, u_int32_t length): Buffer(data,length) {};
		SyncBuffer(const SyncBuffer & src) : Buffer(src) {};
private:
//TODO check if this is ok
//  Mutex mutex_;
	friend class boost::serialization::access;
	template<class Archive>
	void serialize(Archive & ar, const unsigned int version)
	{
//		Lock lock(mutex_);
    ar & length_;
		for(u_int32_t i = 0; i < length_; i++)
			ar & (*this)[i];
	}
};

#endif

==> anytun_0.3.4.orig.tar.gz: anytun-0.3.4/src/syncBuffer.h <==
/*
 *  anytun
 *
 *  The secure anycast tunneling protocol (satp) defines a protocol used
 *  for communication between any combination of unicast and anycast
 *  tunnel endpoints.  It has less protocol overhead than IPSec in Tunnel
 *  mode and allows tunneling of every ETHER TYPE protocol (e.g.
 *  ethernet, ip, arp ...). satp directly includes cryptography and
 *  message authentication based on the methodes used by SRTP.  It is
 *  intended to deliver a generic, scaleable and secure solution for
 *  tunneling and relaying of packets of any protocol.
 *
 *
 *  Copyright (C) 2007-2009 Othmar Gsenger, Erwin Nindl,
 *                          Christian Pointner <satp@wirdorange.org>
 *
 *  This file is part of Anytun.
 *
 *  Anytun is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.
 *
 *  Anytun is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with anytun.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ANYTUN_syncBuffer_h_INCLUDED
#define ANYTUN_syncBuffer_h_INCLUDED

#include <boost/archive/text_oarchive.hpp>
#include <boost/archive/text_iarchive.hpp>
#include "buffer.h"
#include <iostream>
#include "datatypes.h"
#include "threadUtils.hpp"

class SyncBuffer : public Buffer
{
public:
  SyncBuffer() : Buffer() {};
  SyncBuffer(uint32_t length) : Buffer(length) {};
  SyncBuffer(Buffer b): Buffer(b) {};
  SyncBuffer(uint8_t* data, uint32_t length): Buffer(data,length) {};
  SyncBuffer(const SyncBuffer& src) : Buffer(src) {};
private:
  //TODO check if this is ok
  //  Mutex mutex_;
  friend class boost::serialization::access;
  template<class Archive>
  void serialize(Archive& ar, const unsigned int version) {
    //		Lock lock(mutex_);
    ar& length_;
    for(uint32_t i = 0; i < length_; i++) {
      ar & (*this)[i];
    }
  }
};

#endif
